import AsyncStorage from '@react-native-async-storage/async-storage';
import {sendEventToBackend} from '../utils/api';
import {instance} from './sdkState';
import {checkNetworkStatus} from './networkListner';

// const flushQueueSize = 20;
const MAX_EVENT_COUNT = 1000;

export const flush = async () => {
  try {
    if (!instance || instance.eventQueue.length === 0) {
      console.log('No Events to flush or SDK not initialized');
      return;
    }

    const isOnline = await checkNetworkStatus();

    if (!isOnline) {
      console.log('Device is offline. Events will be synced when online.');
      return;
    }

    const eventsToFlush = instance.eventQueue.slice(
      0,
      instance.flushQueueSize || 20,
    );
    // for (let i = 0; i < instance.eventQueue.length; i++) {
    //   const event = instance.eventQueue[i];
    //   try {
    //     // await sendEventToBackend(event.type, event);
    //     await sendEventToBackend(event.type, event);
    //   } catch (error) {
    //     console.error(`Error sending event:`, error?.message);
    //   }
    // }
    await sendEventToBackend(eventsToFlush);
    instance.eventQueue = [];
    await AsyncStorage.setItem('eventQueue', JSON.stringify([]));
    console.log('Event Queue flushed successfully');
  } catch (error) {
    console.log('Error during flush: ', error.message);
  }
};

export const addEventToQueue = async event => {
  if (!instance) {
    throw new Error('SDK not initialized. Please call initializeSDK first.');
  }

  instance.eventQueue.push(event);

  if (instance.eventQueue.length > MAX_EVENT_COUNT) {
    instance.eventQueue = instance.eventQueue.slice(0, MAX_EVENT_COUNT);
  }

  try {
    await AsyncStorage.setItem(
      'eventQueue',
      JSON.stringify(instance.eventQueue),
    );
  } catch (error) {
    console.error('Error saving event to AsyncStorage:', error.message);
  }

  if (instance.eventQueue.length >= (instance.flushQueueSize || 20)) {
    // flush();
    const isOnline = await checkNetworkStatus();
    if (!isOnline) {
      console.log(
        'Device is offline. Events are saved locally and will be sync later',
      );
      return;
    }
    flush();
  }
};
