import AsyncStorage from '@react-native-async-storage/async-storage';
import {ContractSource, EventType, Options, Traits} from '../utils/constants';
import {getDefaultContext} from '../utils/contextUtils';
import {addEventToQueue} from './flush';
import {instance} from './sdkState';
import {getContext} from '../utils/getContext';

export const group = async (
  groupId: string,
  additionalTraits: any = {},
  options: Options = {},
) => {
  try {
    if (!instance) {
      throw new Error('SDK not initialized. Please call initializeSDK first.');
    }

    if (instance.optOutStatus) {
      console.log('User has opted out of tracking. Skipping group event.');
      return;
    }

    if (!groupId) {
      throw new Error('Group ID is required');
    }

    instance.groupId = groupId;
    // instance.traits = {...instance.traits, ...traits};
    const storedTraits = await AsyncStorage.getItem('userTraits');
    const traits = storedTraits ? JSON.parse(storedTraits) : {};

    // const context = options.context || (await getDefaultContext());
    const context = await getContext(options);

    const storedIdentityId = await AsyncStorage.getItem('identityId');

    const payload = {
      type: EventType.GROUP,
      apiKey: instance.apiKey,
      contractSource: ContractSource.REACT_APP,
      schemaVersion: instance?.schemaVersion,
      name: 'ScreenView',
      userProperties: traits,
      contextProperties: {
        ...context, // context properties, for over ride the default context (devicename etc)
        identityId: storedIdentityId,
        fingerPrintId: instance?.fingerprintId,
        sessionId: instance?.sessionId,
      },
      eventProperties: {
        ...additionalTraits,
        groupId,
      }, // optional event properties
      timestamp: Date.now(),
    };
    addEventToQueue(payload);
  } catch (error) {
    console.log('Error sending group event:', error);
    throw error;
  }
};
