import AsyncStorage from '@react-native-async-storage/async-storage';
import {ContractSource, EventType, Options, Traits} from '../utils/constants';
import {instance} from './sdkState';
import {storeTraits} from './getAndSetTraits';
import {getDefaultContext} from '../utils/contextUtils';
import {addEventToQueue} from './flush';
import {getContext} from '../utils/getContext';

export const identify = async (
  userId: string,
  traits: Traits = {},
  options: Options = {},
  eventProperties: Record<string, any> = {},
) => {
  try {
    if (!instance) {
      throw new Error('SDK not initialized. Please call initializeSDK first.');
    }

    await AsyncStorage.setItem('identityId', userId);
    await AsyncStorage.setItem('userTraits', JSON.stringify(traits));

    instance.userId = userId;
    storeTraits(traits);

    const storedIdentityId = await AsyncStorage.getItem('identityId');
    // const context = options.context || (await getDefaultContext());
    const context = await getContext(options);

    const payload = {
      type: EventType.IDENTIFY,
      apiKey: instance.apiKey,
      contractSource: ContractSource.REACT_APP,
      schemaVersion: instance?.schemaVersion,
      name: 'User Identify',
      userProperties: traits, // user properties will go in every API, when we triggered the identify event, then we store this userProperties inside the async storage
      contextProperties: {
        ...context, // context properties, for over ride the default context (devicename etc)
        identityId: storedIdentityId || instance.userId, // Include identityId (userId)
        fingerPrintId: instance?.fingerprintId,
        sessionId: instance?.sessionId,
      },
      eventProperties: eventProperties, // optional event properties
      timestamp: Date.now(),
    };

    addEventToQueue(payload);
  } catch (error) {
    console.log('Error sending identify event', error);
    throw error;
  }
};
