import {Linking} from 'react-native';
import {addEventToQueue} from './flush';
import AsyncStorage from '@react-native-async-storage/async-storage';
import {getDefaultContext} from '../utils/contextUtils';
import {ContractSource, EventType} from '../utils/constants';
import {instance} from './sdkState';
import { getContext } from '../utils/getContext';

export const listenForDeepLinks = () => {
  const handleDeepLink = async event => {
    console.log('Received deep link:', event.url);
    const storedTraits = await AsyncStorage.getItem('userTraits');
    const traits = storedTraits ? JSON.parse(storedTraits) : {};
    const storedIdentityId = await AsyncStorage.getItem('identityId');
    // const context = await getDefaultContext();
    const context = await getContext();

    const eventPayload = {
      type: EventType.TRACK,
      apiKey: instance?.apiKey,
      contractSource: ContractSource.REACT_APP,
      schemaVersion: instance?.schemaVersion,
      name: 'deeplink_url',
      userProperties: traits,
      contextProperties: {
        ...context,
        identityId: storedIdentityId,
        fingerPrintId: instance?.fingerprintId,
        sessionId: instance?.sessionId,
      },
      eventProperties: {
        deeplink_url: event.url,
      },
      timestamp: Date.now(),
    };
    addEventToQueue(eventPayload);
  };

  const urlListener = Linking.addEventListener('url', handleDeepLink);

  // Optional: Check if the app was opened from a deep link when it is first loaded
  Linking.getInitialURL().then(url => {
    if (url) {
      console.log('App opened from deep link:', url);
    }
  });

  return () => {
    urlListener.remove();
  };
};
