import AsyncStorage from '@react-native-async-storage/async-storage';
import {ContractSource, EventType, Options} from '../utils/constants';
import {getDefaultContext} from '../utils/contextUtils';
import {addEventToQueue} from './flush';
import {instance} from './sdkState';
import { getContext } from '../utils/getContext';

export const screen = async (
  category: string | undefined | null = null,
  name: string | undefined | null = '',
  properties: Record<string, any> = {},
  options: Options = {},
) => {
  // all fields are optional
  try {
    if (!instance) {
      throw new Error('SDK not initialized. Please call initializeSDK first.');
    }

    if (instance.optOutStatus) {
      console.log('User has opted out of tracking. Skipping screen event.');
      return;
    }

    // If auto track not enabled
    if (!instance.trackScreenViews && (!category || !name)) {
      throw new Error(
        'Both category and name must be provided for Manually tracking screen views.',
      );
    }

    const storedTraits = await AsyncStorage.getItem('userTraits');
    const traits = storedTraits ? JSON.parse(storedTraits) : {};
    const storedIdentityId = await AsyncStorage.getItem('identityId');

    // const context = options.context || (await getDefaultContext());
    const context = await getContext(options);

    const payload = {
      type: EventType.SCREEN,
      apiKey: instance.apiKey,
      contractSource: ContractSource.REACT_APP,
      schemaVersion: instance?.schemaVersion,
      name: 'ScreenView',
      userProperties: traits, // user properties
      contextProperties: {
        ...context, // context properties, for over ride the default context (devicename etc)
        identityId: storedIdentityId, // Include identityId (userId)
        fingerPrintId: instance?.fingerprintId,
        sessionId: instance?.sessionId,
      },
      eventProperties: {
        category,
        name,
        ...properties,
      },
      timestamp: Date.now(),
    };
    addEventToQueue(payload);
  } catch (error) {
    console.log('Error in screen method', error?.message);
  }
};
