import AsyncStorage from '@react-native-async-storage/async-storage';
import {ContractSource, EventType, Options} from '../utils/constants';
import {getDefaultContext} from '../utils/contextUtils';
import {addEventToQueue} from './flush';
import {instance} from './sdkState';
import {getContext} from '../utils/getContext';

export const trackEvent = async (
  eventName: string,
  properties: Record<string, unknown> | any,
  options: Options = {},
) => {
  if (!instance) {
    throw new Error('SDK not initialized. Please call initializeSDK first.');
  }

  if (instance.optOutStatus) {
    console.log('User has opted out of tracking. Skipping event.');
    return;
  }

  // if (!instance.userId) {
  //   throw new Error('User ID not found. Please call identify first.');
  // }

  if (!eventName) {
    throw new Error('Event name is required');
  }

  const storedTraits = await AsyncStorage.getItem('userTraits');
  const traits = storedTraits ? JSON.parse(storedTraits) : {};

  const storedIdentityId = await AsyncStorage.getItem('identityId');

  // const context = options.context || (await getDefaultContext());
  const context = await getContext(options);

  const payload = {
    type: EventType.TRACK,
    apiKey: instance.apiKey,
    contractSource: ContractSource.REACT_APP,
    schemaVersion: instance?.schemaVersion,
    name: eventName,
    userProperties: traits, // user properties will go in every API, when we triggered the identify event, then we store this userProperties inside the async storage
    contextProperties: {
      ...context, // context properties, for over ride the default context (devicename etc)
      identityId: storedIdentityId, // Include identityId (userId)
      fingerPrintId: instance?.fingerprintId,
      sessionId: instance?.sessionId,
    },
    eventProperties: properties,
    timestamp: Date.now(),
  };

  addEventToQueue(payload);
};
