import {AppState} from 'react-native';
import {addEventToQueue} from './flush';
import AsyncStorage from '@react-native-async-storage/async-storage';
import {getDefaultContext} from '../utils/contextUtils';
import {ContractSource, EventType} from '../utils/constants';
import {instance} from './sdkState';
import {getContext} from '../utils/getContext';

export const trackLifeCycleEvents = () => {
  let currentAppState = AppState.currentState;
  if (instance.optOutStatus) {
    console.log('User has opted out of tracking. Skipping event.');
    return;
  }
  const handleAppStateChange = async (nextAppState: any) => {
    console.log('Current State:', currentAppState, 'Next State:', nextAppState);

    // Track lifecycle events only when state changes
    // if (nextAppState === currentAppState) {
    //   return;
    // }

    currentAppState = nextAppState;

    const storedTraits = await AsyncStorage.getItem('userTraits');
    const traits = storedTraits ? JSON.parse(storedTraits) : {};
    const storedIdentityId = await AsyncStorage.getItem('identityId');
    // const context = await getDefaultContext();
    const context = await getContext();

    const eventPayload = {
      type: EventType.TRACK,
      apiKey: instance?.apiKey,
      contractSource: ContractSource.REACT_APP,
      schemaVersion: instance?.schemaVersion,
      name: '',
      userProperties: traits,
      contextProperties: {
        ...context,
        identityId: storedIdentityId,
        fingerPrintId: instance?.fingerprintId,
        sessionId: instance?.sessionId,
      },
      eventProperties: {},
      timestamp: Date.now(),
    };

    if (nextAppState === 'active') {
      console.log('App has come to the foreground!');
      eventPayload.name = 'app_open';
      addEventToQueue(eventPayload);
    }

    if (nextAppState === 'background') {
      console.log('App has gone to the background!');
      eventPayload.name = 'app_background';
      addEventToQueue(eventPayload);
    }

    if (nextAppState === 'inactive') {
      console.log('App is now inactive!');
      eventPayload.name = 'app_inactive';
      addEventToQueue(eventPayload);
    }
  };

  if (currentAppState === 'active') {
    handleAppStateChange('active');
  }

  const appStateListener = AppState.addEventListener(
    'change',
    handleAppStateChange,
  );

  return () => {
    appStateListener.remove();
  };
};
