import DeviceInfo from 'react-native-device-info';
// import {DefaultContext} from './constants';
import BluetoothStateManager from 'react-native-bluetooth-state-manager';
import NetInfo from '@react-native-community/netinfo';
import * as RNLocalize from 'react-native-localize';

const { name: libraryName, version: libraryVersion } = require('../../package.json');

export const getDefaultContext = async () => {
  if (!DeviceInfo) {
    throw new Error('DeviceInfo module is not available!');
  }

  // Fetch application details
  const appName = await DeviceInfo.getApplicationName();
  const appVersion = await DeviceInfo.getVersion();
  const appBuild = await DeviceInfo.getBuildNumber();

  // Fetch device details(advertisingId,adTrackingEnabled)
  const deviceId = await DeviceInfo.getUniqueId();
  const deviceType = await DeviceInfo.getDeviceType();
  const deviceManufacturer = await DeviceInfo.getManufacturer();
  const deviceModel = await DeviceInfo.getModel();
  const deviceName = await DeviceInfo.getDeviceName();

  // Fetch user Information
  const ip = await DeviceInfo.getIpAddress();

  // Fetch OS details
  const osName = await DeviceInfo.getSystemName();
  const osVersion = await DeviceInfo.getSystemVersion();

  // Fetch bluetoot state (enabled or disabled)
  let bluetoothState = '';
  try {
    bluetoothState = await BluetoothStateManager.getState();
  } catch (error) {
    console.log('error fetching bluetooth state:', error);
  }

  // Fetch Wifi and cellular network
  let networkInfo = {
    type: 'unknown', // wifi, cellular, unknown
    isConnected: false, // Is connected to the network?
    // ipAddress: '',
    isWifi: false, // connect to wifi or not
    isCelluar: false, // is connected to cellular
  };

  try {
    const state = await NetInfo.fetch();
    networkInfo.type = state.type;
    networkInfo.isConnected = state.isConnected; // Whether the device has network access
    // networkInfo.ipAddress = state.details.
    networkInfo.isWifi = state.isWifiEnabled;
    networkInfo.isCelluar = state.type === 'cellular';
  } catch (error) {
    console.log('Error fetching network info:', error);
  }

  const carrier = await DeviceInfo.getCarrier();

  const locales = RNLocalize.getLocales();
  const locale = locales && locales[0] ? locales[0].languageTag : 'en-US';

  return {
    'app.name': appName,
    'app.version': appVersion,
    'app.build': appBuild,
    'device.id': deviceId,
    'device.type': deviceType,
    'device.manufacturer': deviceManufacturer,
    'device.model': deviceModel,
    'device.name': deviceName,
    'library.name': libraryName, 
    'library.version': libraryVersion,
    'user.ip': ip,
    'user.locale': locale,
    'network.bluetooth': bluetoothState,
    'network.carrier': carrier,
    'network.cellular': networkInfo.isCelluar,
    'network.wifi': networkInfo.isWifi,
    'os.name': osName,
    'os.version': osVersion,
  };
};
