import AsyncStorage from '@react-native-async-storage/async-storage';
import {Options} from './constants';
import {getDefaultContext} from './contextUtils';

export const getContext = async (options?: Options) => {
  const defaultContext = await getDefaultContext();
  if (options?.context) {
    const mergedContext = {
      ...defaultContext,
      ...options.context,
    };

    await AsyncStorage.setItem('customContext', JSON.stringify(mergedContext));
    return mergedContext;
  } else {
    const storedContext = await AsyncStorage.getItem('customContext');
    if (storedContext) {
      return JSON.parse(storedContext);
    }    
    return defaultContext; // fallback to default context
  }
};
